#!/bin/bash
###############################################################################
#
# Bash Remediation Script for Standard System Security Profile for Kylin Linux Advanced Server V10
#
# Profile Description:
# This profile contains rules to ensure standard security baseline
# of a Kylin Linux Advanced Server V10 SP3 system. Regardless of your system's workload
# all of these checks should pass.
#
# Profile ID:  kylin-standard
# Benchmark ID:  KYLIN-10
# Benchmark Version:  0.1.39
# XCCDF Version:  1.1
#
# This file was generated by OpenSCAP 1.3.2 using:
# $ oscap xccdf generate fix --profile kylin-standard --fix-type bash xccdf-file.xml
#
# This Bash Remediation Script is generated from an OpenSCAP profile without preliminary evaluation.
# It attempts to fix every selected rule, even if the system is already compliant.
#
# How to apply this Bash Remediation Script:
# $ sudo ./remediation-script.sh
#
###############################################################################

###############################################################################
# BEGIN fix (1 / 52) for 'package_rsh_removed'
###############################################################################
(>&2 echo "Remediating rule 1/52: 'package_rsh_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove rsh

# END fix for 'package_rsh_removed'

###############################################################################
# BEGIN fix (2 / 52) for 'package_rsh-server_removed'
###############################################################################
(>&2 echo "Remediating rule 2/52: 'package_rsh-server_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove rsh-server

# END fix for 'package_rsh-server_removed'

###############################################################################
# BEGIN fix (3 / 52) for 'package_tftp_removed'
###############################################################################
(>&2 echo "Remediating rule 3/52: 'package_tftp_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove tftp

# END fix for 'package_tftp_removed'

###############################################################################
# BEGIN fix (4 / 52) for 'package_tftp-server_removed'
###############################################################################
(>&2 echo "Remediating rule 4/52: 'package_tftp-server_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove tftp-server

# END fix for 'package_tftp-server_removed'

###############################################################################
# BEGIN fix (5 / 52) for 'package_talk_removed'
###############################################################################
(>&2 echo "Remediating rule 5/52: 'package_talk_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove talk

# END fix for 'package_talk_removed'

###############################################################################
# BEGIN fix (6 / 52) for 'package_talk-server_removed'
###############################################################################
(>&2 echo "Remediating rule 6/52: 'package_talk-server_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove talk-server

# END fix for 'package_talk-server_removed'

###############################################################################
# BEGIN fix (7 / 52) for 'package_dovecot_removed'
###############################################################################
(>&2 echo "Remediating rule 7/52: 'package_dovecot_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove dovecot

# END fix for 'package_dovecot_removed'

###############################################################################
# BEGIN fix (8 / 52) for 'package_quagga_removed'
###############################################################################
(>&2 echo "Remediating rule 8/52: 'package_quagga_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove quagga

# END fix for 'package_quagga_removed'

###############################################################################
# BEGIN fix (9 / 52) for 'package_postfix_installed'
###############################################################################
(>&2 echo "Remediating rule 9/52: 'package_postfix_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_postfix_installed' IS MISSING!")

# END fix for 'package_postfix_installed'

###############################################################################
# BEGIN fix (10 / 52) for 'package_samba-common_installed'
###############################################################################
(>&2 echo "Remediating rule 10/52: 'package_samba-common_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_samba-common_installed' IS MISSING!")

# END fix for 'package_samba-common_installed'

###############################################################################
# BEGIN fix (11 / 52) for 'package_cronie_installed'
###############################################################################
(>&2 echo "Remediating rule 11/52: 'package_cronie_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_cronie_installed' IS MISSING!")

# END fix for 'package_cronie_installed'

###############################################################################
# BEGIN fix (12 / 52) for 'package_chrony_installed'
###############################################################################
(>&2 echo "Remediating rule 12/52: 'package_chrony_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_chrony_installed' IS MISSING!")

# END fix for 'package_chrony_installed'

###############################################################################
# BEGIN fix (13 / 52) for 'package_ntp_installed'
###############################################################################
(>&2 echo "Remediating rule 13/52: 'package_ntp_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_ntp_installed' IS MISSING!")

# END fix for 'package_ntp_installed'

###############################################################################
# BEGIN fix (14 / 52) for 'service_kdump_disabled'
###############################################################################
(>&2 echo "Remediating rule 14/52: 'service_kdump_disabled'")
(>&2 echo "FIX FOR THIS RULE 'service_kdump_disabled' IS MISSING!")

# END fix for 'service_kdump_disabled'

###############################################################################
# BEGIN fix (15 / 52) for 'sshd_allow_only_protocol2'
###############################################################################
(>&2 echo "Remediating rule 15/52: 'sshd_allow_only_protocol2'")
(>&2 echo "FIX FOR THIS RULE 'sshd_allow_only_protocol2' IS MISSING!")

# END fix for 'sshd_allow_only_protocol2'

###############################################################################
# BEGIN fix (16 / 52) for 'sshd_disable_rhosts'
###############################################################################
(>&2 echo "Remediating rule 16/52: 'sshd_disable_rhosts'")
(>&2 echo "FIX FOR THIS RULE 'sshd_disable_rhosts' IS MISSING!")

# END fix for 'sshd_disable_rhosts'

###############################################################################
# BEGIN fix (17 / 52) for 'disable_host_auth'
###############################################################################
(>&2 echo "Remediating rule 17/52: 'disable_host_auth'")
(>&2 echo "FIX FOR THIS RULE 'disable_host_auth' IS MISSING!")

# END fix for 'disable_host_auth'

###############################################################################
# BEGIN fix (18 / 52) for 'package_certmonger_removed'
###############################################################################
(>&2 echo "Remediating rule 18/52: 'package_certmonger_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove certmonger

# END fix for 'package_certmonger_removed'

###############################################################################
# BEGIN fix (19 / 52) for 'package_rsyslog_installed'
###############################################################################
(>&2 echo "Remediating rule 19/52: 'package_rsyslog_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_rsyslog_installed' IS MISSING!")

# END fix for 'package_rsyslog_installed'

###############################################################################
# BEGIN fix (20 / 52) for 'package_libreswan_installed'
###############################################################################
(>&2 echo "Remediating rule 20/52: 'package_libreswan_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_libreswan_installed' IS MISSING!")

# END fix for 'package_libreswan_installed'

###############################################################################
# BEGIN fix (21 / 52) for 'package_firewalld_installed'
###############################################################################
(>&2 echo "Remediating rule 21/52: 'package_firewalld_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_firewalld_installed' IS MISSING!")

# END fix for 'package_firewalld_installed'

###############################################################################
# BEGIN fix (22 / 52) for 'package_avahi_removed'
###############################################################################
(>&2 echo "Remediating rule 22/52: 'package_avahi_removed'")
# Function to remove packages on RHEL, Fedora, Debian, and possibly other systems.
#
# Example Call(s):
#
#     package_remove telnet-server
#
function package_remove {

# Load function arguments into local variables
local package="$1"

# Check sanity of the input
if [ $# -ne "1" ]
then
  echo "Usage: package_remove 'package_name'"
  echo "Aborting."
  exit 1
fi

if which dnf ; then
  if rpm -q --quiet "$package"; then
    dnf remove -y "$package"
  fi
elif which yum ; then
  if rpm -q --quiet "$package"; then
    yum remove -y "$package"
  fi
elif which apt-get ; then
  apt-get remove -y "$package"
else
  echo "Failed to detect available packaging system, tried dnf, yum and apt-get!"
  echo "Aborting."
  exit 1
fi

}

package_remove avahi

# END fix for 'package_avahi_removed'

###############################################################################
# BEGIN fix (23 / 52) for 'accounts_no_uid_except_zero'
###############################################################################
(>&2 echo "Remediating rule 23/52: 'accounts_no_uid_except_zero'")
(>&2 echo "FIX FOR THIS RULE 'accounts_no_uid_except_zero' IS MISSING!")

# END fix for 'accounts_no_uid_except_zero'

###############################################################################
# BEGIN fix (24 / 52) for 'gid_passwd_group_same'
###############################################################################
(>&2 echo "Remediating rule 24/52: 'gid_passwd_group_same'")
(>&2 echo "FIX FOR THIS RULE 'gid_passwd_group_same' IS MISSING!")

# END fix for 'gid_passwd_group_same'

###############################################################################
# BEGIN fix (25 / 52) for 'group_unique_id'
###############################################################################
(>&2 echo "Remediating rule 25/52: 'group_unique_id'")
(>&2 echo "FIX FOR THIS RULE 'group_unique_id' IS MISSING!")

# END fix for 'group_unique_id'

###############################################################################
# BEGIN fix (26 / 52) for 'account_unique_group_id'
###############################################################################
(>&2 echo "Remediating rule 26/52: 'account_unique_group_id'")
(>&2 echo "FIX FOR THIS RULE 'account_unique_group_id' IS MISSING!")

# END fix for 'account_unique_group_id'

###############################################################################
# BEGIN fix (27 / 52) for 'account_unique_id'
###############################################################################
(>&2 echo "Remediating rule 27/52: 'account_unique_id'")
(>&2 echo "FIX FOR THIS RULE 'account_unique_id' IS MISSING!")

# END fix for 'account_unique_id'

###############################################################################
# BEGIN fix (28 / 52) for 'set_password_hashing_algorithm_systemauth'
###############################################################################
(>&2 echo "Remediating rule 28/52: 'set_password_hashing_algorithm_systemauth'")
(>&2 echo "FIX FOR THIS RULE 'set_password_hashing_algorithm_systemauth' IS MISSING!")

# END fix for 'set_password_hashing_algorithm_systemauth'

###############################################################################
# BEGIN fix (29 / 52) for 'accounts_password_pam_minlen'
###############################################################################
(>&2 echo "Remediating rule 29/52: 'accounts_password_pam_minlen'")
(>&2 echo "FIX FOR THIS RULE 'accounts_password_pam_minlen' IS MISSING!")

# END fix for 'accounts_password_pam_minlen'

###############################################################################
# BEGIN fix (30 / 52) for 'accounts_password_pam_dcredit'
###############################################################################
(>&2 echo "Remediating rule 30/52: 'accounts_password_pam_dcredit'")
(>&2 echo "FIX FOR THIS RULE 'accounts_password_pam_dcredit' IS MISSING!")

# END fix for 'accounts_password_pam_dcredit'

###############################################################################
# BEGIN fix (31 / 52) for 'accounts_password_pam_minclass'
###############################################################################
(>&2 echo "Remediating rule 31/52: 'accounts_password_pam_minclass'")
(>&2 echo "FIX FOR THIS RULE 'accounts_password_pam_minclass' IS MISSING!")

# END fix for 'accounts_password_pam_minclass'

###############################################################################
# BEGIN fix (32 / 52) for 'accounts_password_pam_ocredit'
###############################################################################
(>&2 echo "Remediating rule 32/52: 'accounts_password_pam_ocredit'")
(>&2 echo "FIX FOR THIS RULE 'accounts_password_pam_ocredit' IS MISSING!")

# END fix for 'accounts_password_pam_ocredit'

###############################################################################
# BEGIN fix (33 / 52) for 'accounts_password_pam_lcredit'
###############################################################################
(>&2 echo "Remediating rule 33/52: 'accounts_password_pam_lcredit'")
(>&2 echo "FIX FOR THIS RULE 'accounts_password_pam_lcredit' IS MISSING!")

# END fix for 'accounts_password_pam_lcredit'

###############################################################################
# BEGIN fix (34 / 52) for 'accounts_password_pam_ucredit'
###############################################################################
(>&2 echo "Remediating rule 34/52: 'accounts_password_pam_ucredit'")
(>&2 echo "FIX FOR THIS RULE 'accounts_password_pam_ucredit' IS MISSING!")

# END fix for 'accounts_password_pam_ucredit'

###############################################################################
# BEGIN fix (35 / 52) for 'no_name_contained_in_password'
###############################################################################
(>&2 echo "Remediating rule 35/52: 'no_name_contained_in_password'")
(>&2 echo "FIX FOR THIS RULE 'no_name_contained_in_password' IS MISSING!")

# END fix for 'no_name_contained_in_password'

###############################################################################
# BEGIN fix (36 / 52) for 'verify_owner_password'
###############################################################################
(>&2 echo "Remediating rule 36/52: 'verify_owner_password'")
(>&2 echo "FIX FOR THIS RULE 'verify_owner_password' IS MISSING!")

# END fix for 'verify_owner_password'

###############################################################################
# BEGIN fix (37 / 52) for 'accounts_umask_etc_bashrc'
###############################################################################
(>&2 echo "Remediating rule 37/52: 'accounts_umask_etc_bashrc'")
(>&2 echo "FIX FOR THIS RULE 'accounts_umask_etc_bashrc' IS MISSING!")

# END fix for 'accounts_umask_etc_bashrc'

###############################################################################
# BEGIN fix (38 / 52) for 'file_owner_etc_gshadow'
###############################################################################
(>&2 echo "Remediating rule 38/52: 'file_owner_etc_gshadow'")

chown root /etc/gshadow

# END fix for 'file_owner_etc_gshadow'

###############################################################################
# BEGIN fix (39 / 52) for 'file_groupowner_etc_passwd'
###############################################################################
(>&2 echo "Remediating rule 39/52: 'file_groupowner_etc_passwd'")

chgrp root /etc/passwd

# END fix for 'file_groupowner_etc_passwd'

###############################################################################
# BEGIN fix (40 / 52) for 'file_groupowner_etc_gshadow'
###############################################################################
(>&2 echo "Remediating rule 40/52: 'file_groupowner_etc_gshadow'")

chgrp root /etc/gshadow

# END fix for 'file_groupowner_etc_gshadow'

###############################################################################
# BEGIN fix (41 / 52) for 'file_owner_etc_passwd'
###############################################################################
(>&2 echo "Remediating rule 41/52: 'file_owner_etc_passwd'")

chown root /etc/passwd

# END fix for 'file_owner_etc_passwd'

###############################################################################
# BEGIN fix (42 / 52) for 'file_permissions_etc_gshadow'
###############################################################################
(>&2 echo "Remediating rule 42/52: 'file_permissions_etc_gshadow'")

chmod 0000 /etc/gshadow

# END fix for 'file_permissions_etc_gshadow'

###############################################################################
# BEGIN fix (43 / 52) for 'file_permissions_etc_passwd'
###############################################################################
(>&2 echo "Remediating rule 43/52: 'file_permissions_etc_passwd'")

chmod 0644 /etc/passwd

# END fix for 'file_permissions_etc_passwd'

###############################################################################
# BEGIN fix (44 / 52) for 'file_permissions_ungroupowned'
###############################################################################
(>&2 echo "Remediating rule 44/52: 'file_permissions_ungroupowned'")
(>&2 echo "FIX FOR THIS RULE 'file_permissions_ungroupowned' IS MISSING!")

# END fix for 'file_permissions_ungroupowned'

###############################################################################
# BEGIN fix (45 / 52) for 'no_files_unowned_by_user'
###############################################################################
(>&2 echo "Remediating rule 45/52: 'no_files_unowned_by_user'")
(>&2 echo "FIX FOR THIS RULE 'no_files_unowned_by_user' IS MISSING!")

# END fix for 'no_files_unowned_by_user'

###############################################################################
# BEGIN fix (46 / 52) for 'audit_rules_privileged_commands'
###############################################################################
(>&2 echo "Remediating rule 46/52: 'audit_rules_privileged_commands'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands' IS MISSING!")

# END fix for 'audit_rules_privileged_commands'

###############################################################################
# BEGIN fix (47 / 52) for 'audit_rules_usergroup_modification'
###############################################################################
(>&2 echo "Remediating rule 47/52: 'audit_rules_usergroup_modification'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_usergroup_modification' IS MISSING!")

# END fix for 'audit_rules_usergroup_modification'

###############################################################################
# BEGIN fix (48 / 52) for 'package_audit_installed'
###############################################################################
(>&2 echo "Remediating rule 48/52: 'package_audit_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_audit_installed' IS MISSING!")

# END fix for 'package_audit_installed'

###############################################################################
# BEGIN fix (49 / 52) for 'package_dconf_installed'
###############################################################################
(>&2 echo "Remediating rule 49/52: 'package_dconf_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_dconf_installed' IS MISSING!")

# END fix for 'package_dconf_installed'

###############################################################################
# BEGIN fix (50 / 52) for 'package_dracut-fips_installed'
###############################################################################
(>&2 echo "Remediating rule 50/52: 'package_dracut-fips_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_dracut-fips_installed' IS MISSING!")

# END fix for 'package_dracut-fips_installed'

###############################################################################
# BEGIN fix (51 / 52) for 'ensure_gpgcheck_never_disabled'
###############################################################################
(>&2 echo "Remediating rule 51/52: 'ensure_gpgcheck_never_disabled'")
(>&2 echo "FIX FOR THIS RULE 'ensure_gpgcheck_never_disabled' IS MISSING!")

# END fix for 'ensure_gpgcheck_never_disabled'

###############################################################################
# BEGIN fix (52 / 52) for 'ensure_gpgcheck_globally_activated'
###############################################################################
(>&2 echo "Remediating rule 52/52: 'ensure_gpgcheck_globally_activated'")
(>&2 echo "FIX FOR THIS RULE 'ensure_gpgcheck_globally_activated' IS MISSING!")

# END fix for 'ensure_gpgcheck_globally_activated'

